R/memofunc.R
memofunc-package.RdThe memofunc package provides tools for function memoization with
explicit cache key semantics and pluggable storage backends.
Memoized functions: cached calls still behave like normal R functions
Deterministic keys: cache keys combine function identity and normalized call arguments
Configurable storage: memory, file, and object provider backends
Runtime controls: force recomputation or perform dry-run cache checks
memo - memoize a function
is.memo - is the given function a memo
memo.function - get a memo's origional function
memo.cache - get a memo's cache storage